==> openjdk-17_17.0.17~8ea.orig.tar.xz: openjdk-17-17.0.17~8ea/src/hotspot/share/jfr/support/jfrKlassUnloading.hpp <==
/*
 * Copyright (c) 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_JFR_SUPPORT_JFRKLASSUNLOADING_HPP
#define SHARE_JFR_SUPPORT_JFRKLASSUNLOADING_HPP

#include "jfr/utilities/jfrTypes.hpp"
#include "memory/allocation.hpp"

class Klass;

class JfrKlassUnloading : AllStatic {
 public:
  static bool on_unload(const Klass* k);
  static int64_t event_class_count();
  static bool is_unloaded(traceid klass_id, bool previous_epoch = false);
  static void sort(bool previous_epoch = false);
  static void clear();
};

#endif // SHARE_JFR_SUPPORT_JFRKLASSUNLOADING_HPP

==> openjdk-26_26~26ea.orig.tar.xz: openjdk-26-26~26ea/src/hotspot/share/jfr/support/jfrKlassUnloading.hpp <==
/*
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_JFR_SUPPORT_JFRKLASSUNLOADING_HPP
#define SHARE_JFR_SUPPORT_JFRKLASSUNLOADING_HPP

#include "jfr/utilities/jfrTypes.hpp"
#include "memory/allStatic.hpp"

class Klass;

class JfrKlassUnloading : AllStatic {
 public:
  static bool on_unload(const Klass* k);
  static int64_t event_class_count();
  static bool is_unloaded(traceid klass_id, bool previous_epoch = false);
  static void clear();
};

#endif // SHARE_JFR_SUPPORT_JFRKLASSUNLOADING_HPP
